# lightcards
Terminal flashcards from Markdown.

## Installation
### From PyPI
```
pip install lightcards
```

### From Git
#### Main branch (stable)
```
pip install git+https://git.sr.ht/~armaan/lightcards
```

#### Development branch
```
pip install git+https://git.sr.ht/~armaan/lightcards@devel
```

## Usage
See `lightcards --help` or `man lightcards` for usage information.

## Input file
`contrib/example.md` is an example input file. Lightcards takes the first table from a valid Markdown or HTML file. Each row is a card, and the two columns are the front and back.

## License
Copyright Armaan Bhojwani 2021, MIT license
